@@ -2,7 +2,7 @@
  * This file is part of gtatool, a tool to manipulate Generic Tagged Arrays
  * (GTAs).
  *
- * Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+ * Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -74,6 +74,7 @@ typedef struct
             AVAILABLE ? gtatool_ ## FNBASE ## _help : NULL }
 #endif
 
+CMD_DECL(combine)
 CMD_DECL(component_add)
 CMD_DECL(component_compute)
 CMD_DECL(component_convert)
@@ -84,6 +85,7 @@ CMD_DECL(component_set)
 CMD_DECL(component_split)
 CMD_DECL(compress)
 CMD_DECL(create)
+CMD_DECL(diff)
 CMD_DECL(dimension_add)
 CMD_DECL(dimension_extract)
 CMD_DECL(dimension_flatten)
@@ -144,6 +146,7 @@ CMD_DECL(version)
 
 static cmd_t cmds[] =
 {
+    CMD("combine",           array,      combine,           true,          BUILTIN),
     CMD("component-add",     component,  component_add,     true,          BUILTIN),
     CMD("component-compute", component,  component_compute, WITH_MUPARSER, "component-compute"),
     CMD("component-convert", component,  component_convert, true,          BUILTIN),
@@ -154,6 +157,7 @@ static cmd_t cmds[] =
     CMD("component-split",   component,  component_split,   true,          BUILTIN),
     CMD("compress",          array,      compress,          true,          BUILTIN),
     CMD("create",            array,      create,            true,          BUILTIN),
+    CMD("diff",              array,      diff,              true,          BUILTIN),
     CMD("dimension-add",     dimension,  dimension_add,     true,          BUILTIN),
     CMD("dimension-extract", dimension,  dimension_extract, true,          BUILTIN),
     CMD("dimension-flatten", dimension,  dimension_flatten, true,          BUILTIN),
