@@ -2,7 +2,7 @@
  * This file is part of gtatool, a tool to manipulate Generic Tagged Arrays
  * (GTAs).
  *
- * Copyright (C) 2010, 2011
+ * Copyright (C) 2010, 2011, 2013
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -127,8 +127,13 @@ extern "C" int gtatool_to_mat(int argc, char *argv[])
                 msg::wrn(array_name + ": ignoring empty array");
                 continue;
             }
+#if MATIO_VERSION >= 150
+            enum matio_classes class_type;
+            enum matio_types data_type;
+#else
             int class_type;
             int data_type;
+#endif
             bool is_complex = false;
             switch (ihdr.component_type(0))
             {
@@ -200,23 +205,39 @@ extern "C" int gtatool_to_mat(int argc, char *argv[])
             {
                 rank = 2;
             }
+#if MATIO_VERSION >= 150
+            std::vector<size_t> dims(rank);
+            for (uintmax_t i = 0; i < ohdr.dimensions(); i++)
+            {
+                dims[i] = checked_cast<size_t>(ohdr.dimension_size(i));
+            }
+#else
             std::vector<int> dims(rank);
             for (uintmax_t i = 0; i < ohdr.dimensions(); i++)
             {
                 dims[i] = checked_cast<int>(ohdr.dimension_size(i));
             }
+#endif
             if (ohdr.dimensions() < 2)
             {
                 dims[1] = 1;
             }
+#if MATIO_VERSION >= 150
+            int opt = MAT_F_DONT_COPY_DATA;
+#else
             int opt = MEM_CONSERVE;
+#endif
             if (is_complex)
             {
                 opt |= MAT_F_COMPLEX;
             }
             void *data = odata.ptr();
             blob tmp_data;
+#if MATIO_VERSION >= 150
+            mat_complex_split_t split_data;
+#else
             struct ComplexSplit split_data;
+#endif
             if (is_complex)
             {
                 tmp_data.resize(checked_cast<size_t>(ohdr.data_size()));
@@ -255,7 +276,13 @@ extern "C" int gtatool_to_mat(int argc, char *argv[])
             {
                 throw exc("cannot create MATLAB variable");
             }
-            if (Mat_VarWrite(mat, matvar, 0) != 0)
+            if (Mat_VarWrite(mat, matvar,
+#if MATIO_VERSION >= 150
+                        MAT_COMPRESSION_NONE
+#else
+                        COMPRESSION_NONE
+#endif
+                        ) != 0)
             {
                 throw exc("cannot write MATLAB variable");
             }
