@@ -2,7 +2,7 @@
  * This file is part of gtatool, a tool to manipulate Generic Tagged Arrays
  * (GTAs).
  *
- * Copyright (C) 2010, 2011
+ * Copyright (C) 2010, 2011, 2013
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -43,7 +43,7 @@ extern "C" void gtatool_dimension_reorder_help(void)
             "dimension-reorder [-i|--indices=<i0>[,<i1>[,...]]] [<files>...]\n"
             "\n"
             "Reorders the dimensions of the input GTAs into the given new order.\n"
-            "The input GTAs must be uncompressed and seekable for this purpose.\n"
+            "The default is to make no changes.\n"
             "Example: dimension-reorder -i 1,0 matrix.gta > transposed.gta");
 }
 
@@ -92,20 +92,22 @@ extern "C" int gtatool_dimension_reorder(int argc, char *argv[])
         array_loop.start(arguments, "");
         while (array_loop.read(hdri, namei))
         {
-            if (!fio::seekable(array_loop.file_in()))
-            {
-                throw exc(array_loop.filename_in() + ": input is not seekable");
-            }
-            if (hdri.compression() != gta::none)
-            {
-                throw exc(namei + ": array is compressed");
-            }
             if (!indices.value().empty() && hdri.dimensions() != indices.value().size())
             {
                 throw exc(namei + ": array has " + str::from(hdri.dimensions())
                         + " dimensions while list of indices has " + str::from(indices.value().size()));
             }
-            uintmax_t data_offset = fio::tell(array_loop.file_in(), array_loop.filename_in());
+            uintmax_t data_offset = 0;
+            FILE *fbuf = NULL;
+            gta::header hbuf;
+            if (!fio::seekable(array_loop.file_in()) || hdri.compression() != gta::none)
+            {
+                buffer_data(hdri, array_loop.file_in(), hbuf, &fbuf);
+            }
+            else
+            {
+                data_offset = fio::tell(array_loop.file_in(), array_loop.filename_in());
+            }
             hdro = hdri;
             hdro.set_compression(gta::none);
             if (!indices.value().empty())
@@ -141,11 +143,25 @@ extern "C" int gtatool_dimension_reorder(int argc, char *argv[])
                         in_indices[i] = out_indices[i];
                     }
                 }
-                hdri.read_block(array_loop.file_in(), data_offset, &(in_indices[0]), &(in_indices[0]), element.ptr());
+                if (fbuf)
+                {
+                    hbuf.read_block(fbuf, 0, &(in_indices[0]), &(in_indices[0]), element.ptr());
+                }
+                else
+                {
+                    hdri.read_block(array_loop.file_in(), data_offset, &(in_indices[0]), &(in_indices[0]), element.ptr());
+                }
                 element_loop.write(element.ptr());
             }
-            fio::seek(array_loop.file_in(), data_offset, SEEK_SET, array_loop.filename_in());
-            array_loop.skip_data(hdri);
+            if (fbuf)
+            {
+                fclose(fbuf);
+            }
+            else
+            {
+                fio::seek(array_loop.file_in(), data_offset, SEEK_SET, array_loop.filename_in());
+                array_loop.skip_data(hdri);
+            }
         }
         array_loop.finish();
     }
