@@ -2,7 +2,7 @@
  * This file is part of gtatool, a tool to manipulate Generic Tagged Arrays
  * (GTAs).
  *
- * Copyright (C) 2010, 2011, 2012
+ * Copyright (C) 2010, 2011, 2012, 2013
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -37,11 +37,11 @@
 #include <QDir>
 #include <QStringList>
 #include <QComboBox>
+#include <QSpinBox>
+#include <QGridLayout>
 
 #include <gta/gta.hpp>
 
-#include "fio.h"        // For a fixed off_t on W32
-
 
 class MyTabWidget : public QTabWidget
 {
@@ -92,6 +92,7 @@ class ArrayWidget : public QWidget
 Q_OBJECT
 
 private:
+    size_t _index;
     gta::header *_header;
     QLineEdit *_dimensions_ledt;
     QLineEdit *_components_ledt;
@@ -104,7 +105,7 @@ private slots:
     void taglist_changed(gta::header *header, int type, uintmax_t index);
 
 public:
-    ArrayWidget(gta::header *_header, QWidget *parent = NULL);
+    ArrayWidget(size_t index, gta::header *_header, QWidget *parent = NULL);
     ~ArrayWidget();
 
     void saved();
@@ -113,7 +114,7 @@ public slots:
     void update();
 
 signals:
-    void changed(gta::header *header);
+    void changed(size_t index);
 };
 
 class FileWidget : public QWidget
@@ -125,10 +126,16 @@ private:
     std::string _save_name;
     bool _is_changed;
     std::vector<gta::header *> _headers;
-    MyTabWidget *_arrays_widget;
+    std::vector<bool> _array_changed;
+    QLabel *_array_label;
+    QSpinBox *_array_spinbox;
+    QGridLayout *_array_widget_layout;
+    ArrayWidget* _array_widget;
 
 private slots:
-    void array_changed(gta::header *header);
+    void update_label();
+    void update_array();
+    void array_changed(size_t index);
 
 public:
 
@@ -162,9 +169,9 @@ public:
         return _headers;
     }
 
-    MyTabWidget *arrays_widget()
+    int array_index() const
     {
-        return _arrays_widget;
+        return _array_spinbox->value();
     }
 
     void set_file_name(const std::string &file_name);
@@ -252,7 +259,9 @@ private slots:
     void stream_merge();
     void stream_split();
     void stream_extract();
+    void array_combine();
     void array_create();
+    void array_diff();
     void array_extract();
     void array_fill();
     void array_merge();
