@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-# Copyright (C) 2010, 2011
+# Copyright (C) 2010, 2011, 2013
 # Martin Lambers <marlam@marlam.de>
 #
 # Copying and distribution of this file, with or without modification, are
@@ -22,4 +22,7 @@ $GTA create -d 10 \
 	-v "      0,   1,    2,    3,     4,    5,     6,    7,     8,    0.1,    0.2, 0.3,0.4, 0.5,0.6" \
 	> "$TMPD"/b.gta
 
+$GTA create -d 10 -n5 > "$TMPD"/empty0.gta
+$GTA create -c uint8 -n5 > "$TMPD"/empty1.gta
+
 rm -r "$TMPD"
